summaryrefslogtreecommitdiffstats
path: root/kalarm/kalarmapp.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kalarm/kalarmapp.cpp')
-rw-r--r--kalarm/kalarmapp.cpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/kalarm/kalarmapp.cpp b/kalarm/kalarmapp.cpp
index d9adbf7ce..713467381 100644
--- a/kalarm/kalarmapp.cpp
+++ b/kalarm/kalarmapp.cpp
@@ -94,7 +94,7 @@ TQString KAlarmApp::mFatalMessage;
* Construct the application.
*/
KAlarmApp::KAlarmApp()
- : KUniqueApplication(),
+ : TDEUniqueApplication(),
mInitialised(false),
mDcopHandler(new DcopHandler()),
#ifdef OLD_DCOP
@@ -244,7 +244,7 @@ bool KAlarmApp::restoreSession()
}
/******************************************************************************
* Called for a KUniqueApplication when a new instance of the application is
* started.
*/
int KAlarmApp::newInstance()
@@ -834,7 +834,7 @@ void KAlarmApp::doQuit(TQWidget* parent)
void KAlarmApp::commitData(TQSessionManager& sm)
{
mSessionClosingDown = true;
- KUniqueApplication::commitData(sm);
+ TDEUniqueApplication::commitData(sm);
mSessionClosingDown = false; // reset in case shutdown is cancelled
}
@@ -244,7 +244,7 @@ bool KAlarmApp::restoreSession()
}
/******************************************************************************
-* Called for a KUniqueApplication when a new instance of the application is
+* Called for a TDEUniqueApplication when a new instance of the application is
* started.
*/